# glest: Estimation of the grouping loss of a probabilistic classifier

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/aperezlebel/glest.git/HEAD?labpath=examples%2Fexample.ipynb)
[![codecov](https://codecov.io/gh/aperezlebel/glest/graph/badge.svg?token=KPDTI0WGUT)](https://codecov.io/gh/aperezlebel/glest)
[![CI](https://github.com/aperezlebel/glest/actions/workflows/ci.yml/badge.svg)](https://github.com/aperezlebel/glest/actions/workflows/ci.yml)


## Install

From PyPi:
```
pip install glest
```

From source:
```
pip install git+https://github.com/aperezlebel/glest.git
```

## Cite

```bibtex
@inproceedings{perez-lebel2023,
    title={Beyond calibration: estimating the grouping loss of modern neural networks},
    author={Alexandre Perez-Lebel and Marine Le Morvan and Gaël Varoquaux},
    booktitle={Proceedings of the International Conference on Learning Representations},
    year={2023},
    url={https://doi.org/10.48550/arXiv.2210.16315}
}
```
